%%

%%

clear all
close all

% DATASET INPUT
                    DATA = xlsread('.\DATASET.csv');
                    r=DATA(:,1);    %secondary cracking ratio
                    Lw=DATA(:,2); %wall length (mm)
                    Ar=DATA(:,3);   %aspect ratio
                    for i=1:length(Ar)
                        He(i,1)=Ar(i)*Lw(i);  %effective height (mm) or shear-span ratio
                    end
                    ALR=DATA(:,4);  %Axial load ratio
                    v=DATA(:,5);    %shear stress parameter
                    Lp=DATA(:,6);   %plastic hinge length (mm)
                    Type=DATA(:,7);   %plastic hinge length (mm)
                    clear DATA

% PCK PARAMETERS NEEDED                    
                    DATA = xlsread('.\PCK_para.csv');
                    fy=DATA(:,1);    %yield strength long. steel
                    fu=DATA(:,2); %ultimate strength long. steel
                    dbl=DATA(:,3);   %long. reo diameter
                    fc=DATA(:,4);  %compression strength
                    psh=DATA(:,5);  %trans reo ratio
                    clear DATA                    

% VALIDATED DATA
                                      
%% FIGURE 1 - 0.5Lw

clear LOBF_x LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5];  

%Lp estimate
for i=1:length(Lw)
    Lp_est(i,1)=0.5*Lw(i);
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'a)','Color','black','FontSize',12) 
%text(0.5,4.9,'{\it L_p=0.5L_w}','Color','black','FontSize',8) 
text(0.5,4.9,'{\itEqn. 6}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(0.2,4.4,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_0.5Lw.tif');
copyfile Lp_0.5Lw.tif '.\Images\'
delete Lp_0.5Lw.tif
close all
clear Lp_est

%% FIGURE 2 - PCK

clear LOBF_x LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5];  

%Lp estimate
for i=1:length(Lw)
    k=0.2*((fu(i)/fy(i))-1);
    if k <= 0.08
        Lp_est(i,1)=k*He(i)+0.2*Lw(i)+0.022*(1.1*fy(i)*dbl(i));
    else
        Lp_est(i,1)=0.08*He(i)+0.2*Lw(i)+0.022*(1.1*fy(i)*dbl(i));
    end
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'b)','Color','black','FontSize',12) 
%text(0,4.7,'{\it L_p=kH_e+0.2L_w+L_s_p}','Color','black','FontSize',8) 
text(0.5,4.7,'{\itEqn. 7}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(0.3,4.2,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_PCK.tif');
copyfile Lp_PCK.tif '.\Images\'
delete Lp_PCK.tif
close all
clear Lp_est


%% FIGURE 3 - Eurocode8

clear LOBF_y LOBF_x

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5]; 

%Lp estimate
for i=1:length(Lw)
        Lp_est(i,1)=Ar(i)/30 +0.2*Lw(i)+0.11*((dbl(i)*fy(i))/sqrt(fc(i)));
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'c)','Color','black','FontSize',12) 
%text(0.3,5.05,'{\it L_p=(L_v /_ 30)+0.2L_w+L_s_p_2}','Color','black','FontSize',8) 
text(4,1,2,'{\itEqn. 8}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(3.2,0.5,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_EUR8.tif');
copyfile Lp_EUR8.tif '.\Images\'
delete Lp_EUR8.tif
close all
clear Lp_est


%% FIGURE 4 - BISKINIS & FARDIS

clear LOBF_y LOBF_x

%LINE OF UNITY
LOBF_x=[0;4.7];
LOBF_y=[0;4.7]; 

%Lp estimate
for i=1:length(Lw)
        Lp_est(i,1)=0.2*Lw(i)*(1+(1/3)*min(9,Ar(i)));
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'d)','Color','black','FontSize',12) 
%text(0.2,5,'{\it L_p=0.2L_w[1+(1/3)L_v]}','Color','black','FontSize',8) 
text(0.5,5,'{\itEqn. 9}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(0.35,4.5,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_B&F.tif');
copyfile Lp_B&F.tif '.\Images\'
delete Lp_B&F.tif
close all
clear Lp_est

%% FIGURE 5 - BOHL AND ADEBAR
clear LOBF_y LOBF_x

%LINE OF UNITY
LOBF_x=[0;4.7];
LOBF_y=[0;4.7]; 

%Lp estimate
for i=1:length(Lw)
    if (0.2*Lw(i)+0.05*He(i))*(1-15*ALR(i))<=0.8*Lw(i)
        Lp_est(i,1)=(0.2*Lw(i)+0.05*He(i))*(1-15*ALR(i));
    else
        Lp_est(i,1)=0.8*Lw(i);        
    end        
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'d)','Color','black','FontSize',12) 
%text(0.1,5.05,'{\it L_p=(0.2L_w+0.05H_e)(1-1.5ALR)}','Color','black','FontSize',8) 
text(4,1.0,'{\itEqn. 9}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(3.2,0.5,['{\it R^2=}',num2str(correlation,1)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_B&A.tif');
copyfile Lp_B&A.tif '.\Images\'
delete Lp_B&A.tif
close all
clear Lp_est


%% FIGURE 6 - KAZAZ

clear LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5]; 

%Lp estimate
for i=1:length(Lw)
        Lp_est(i,1)=0.27*Lw(i)*(1-ALR(i))*(1-((fy(i)*psh(i))/fc(i)))*(Ar(i))^0.45;
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'e)','Color','black','FontSize',12) 
%text(0.1,4.99,'{\it L_p=0.27L_w(1-ALR)...}','Color','black','FontSize',8) 
%text(0.4,4.60,'{\it...[1-(f_y\rho_s_h)/f\prime_c](L_v)^{0.45}}','Color','black','FontSize',8) 
text(0.6,4.60,'{\itEqn. 10}','Color','black','FontSize',8) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(0.3,4,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_KAZAZ.tif');
copyfile Lp_KAZAZ.tif '.\Images\'
delete Lp_KAZAZ.tif
close all
clear Lp_est

%% FIGURE 6 - THIS STUDY

clear LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5]; 

%Lp estimate
for i=1:length(Lw)
        Lp_est(i,1)=r(i)*(0.13*Lw(i)+2.2*(He(i))^0.6)*(1-0.37*ALR(i))*(1-0.07*log(v(i)));
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'a)','Color','black','FontSize',12) 
text(3.8,1.3,'{\itEqn. 20}','Color','black','FontSize',9) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(3.5,0.8,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_this_study.tif');
copyfile Lp_this_study.tif '.\Images\'
delete Lp_this_study.tif
close all
clear Lp_est

%% FIGURE X - HOULT ET AL. (2018)

clear LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5]; 

%Lp estimate
for i=1:length(Lw)
    if (0.1*Lw(i)+0.075*He(i))*(1-6*ALR(i))>0.5*Lw(i)
        Lp_est(i,1)=0.5*Lw(i);        
    else
        Lp_est(i,1)=(0.1*Lw(i)+0.075*He(i))*(1-6*ALR(i));
    end
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'f)','Color','black','FontSize',12) 
text(3.8,1.3,'{\itEqn. 13}','Color','black','FontSize',9) 
correlation_coeff = corr2(Lp,Lp_est);
correlation=power(correlation_coeff,2);
text(3.5,0.8,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_Hoult.tif');
copyfile Lp_Hoult.tif '.\Images\'
delete Lp_Hoult.tif
close all
clear Lp_est


%% VALIDATED DATA, EQN FOR BUILDING CODES

% DATASET INPUT (Validated)

                    DATA = xlsread('.\DATASET_Validated.csv');
                    Lwv=DATA(:,1); %wall length (mm)
                    Arv=DATA(:,2);   %aspect ratio
                    for i=1:length(Lwv)
                        Hev(i,1)=Arv(i)*Lwv(i);  %effective height (mm) or shear-span ratio
                    end
                    ALRv=DATA(:,3);  %Axial load ratio
                    vv=DATA(:,4);    %shear stress parameter
                    Lpv=DATA(:,5);   %plastic hinge length (mm)
                    tw=DATA(:,6);   %thickness (mm)
                    clear DATA

                    clear LOBF_y

%LINE OF UNITY
LOBF_x=[0;5];
LOBF_y=[0;5]; 

%LINE2
LOBF_x2=[0;3.4];
LOBF_y2=[0;1.5746*3.4];

%Lp estimate
%for i=1:length(Lwv)
        %if (-0.1*Lwv(i)*vv(i)+450*Hev(i)^0.37)*(1-1.5*ALRv(i)) > 0.5*Lwv(i)
            %Lp_est(i,1)=0.5*Lwv(i);
        %else
            %Lp_est(i,1)=(-0.1*Lwv(i)*vv(i)+450*Hev(i)^0.37)*(1-1.5*ALRv(i));
        %end
%end

for i=1:length(Lwv)
        if (0.05*Hev(i)+0.2*Lwv(i)*vv(i))*(1-2*ALRv(i)) > 0.8*Lwv(i)
            Lp_est(i,1)=0.8*Lwv(i);
        elseif (0.05*Hev(i)+0.2*Lwv(i)*vv(i))*(1-2*ALRv(i)) < 3*tw(i)
            Lp_est(i,1)=3*tw(i);
        else
            Lp_est(i,1)=(0.05*Hev(i)+0.2*Lwv(i)*vv(i))*(1-2*ALRv(i));
        end
end

fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lp_est/1000,Lpv/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y,'k-','color',[1 0 0],'LineWidth',2); hold on
plot(LOBF_x2,LOBF_y2,'k--','color',[1 0 0],'LineWidth',2); hold on
ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 5 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:1:5]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Estimated {\itL_p} [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Observed {\itL_p} [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.65,5*0.9,'b)','Color','black','FontSize',12) 
text(3.6,1.3,'{\itEqn. 21}','Color','black','FontSize',9) 
correlation_coeff = corr2(Lpv,Lp_est);
correlation=power(correlation_coeff,2);
text(3.0,0.8,['{\it R^2=}',num2str(correlation,2)],'Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_code.tif');
copyfile Lp_code.tif '.\Images\'
delete Lp_code.tif
close all
clear Lp_est
