%%

%%

clear all
close all

% DATASET INPUT
                    DATA = xlsread('.\DATASET.csv');
                    r=DATA(:,1);    %secondary cracking ratio
                    Lw=DATA(:,2); %wall length (mm)
                    Ar=DATA(:,3);   %aspect ratio
                    for i=1:length(Ar)
                        He(i,1)=Ar(i)*Lw(i);  %effective height (mm) or shear-span ratio
                    end
                    ALR=DATA(:,4);  %Axial load ratio
                    v=DATA(:,5);    %shear stress parameter
                    Lp=DATA(:,6);   %plastic hinge length (mm)
                    clear DATA
                    

%% FIGURE 1

% WALL LENGTH

%LOBF equation
LOBF_x=[1000:100:9000];
LOBF_y=0.2382*LOBF_x+279.18;
% Wall Length 
fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(Lw,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y/1000,'k--','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 10000 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:2500:10000]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Wall Length ({\itL_w}) [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Plastic Hinge Length ({\itL_p}) [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-1200,5*0.9,'b)','Color','black','FontSize',12) 
text(1000,5*0.95,'{\it R^2=0.54}','Color','red','FontSize',10) 
text(500,5*0.85,'0.238{\itL_w}+279','Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_Lw.tif');
copyfile Lp_Lw.tif '.\Images\'
delete Lp_Lw.tif
close all
clear LOBF_x LOBF_y

%% FIGURE 2

% SECONDARY CRACKING

%LOBF equation
LOBF_x=[0.2:0.025:1];
for i=1:length(LOBF_x)
    LOBF_y(i)=107.25*exp(LOBF_x(i)*2.3384);
end
% Wall Length 
fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(r,Lp/1000,'MarkerEdgeColor',[0.20 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y/1000,'k--','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.22    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 1.2 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:0.2:1.2]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Secondary Cracking Ratio ({\itr})');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Plastic Hinge Length ({\itL_p}) [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.15,5*0.9,'a)','Color','black','FontSize',12) 
text(0.2,5*0.95,'{\it R^2=0.04}','Color','red','FontSize',10) 
text(0.1,5*0.85,'107{\ite}^{2.34{\itL_w}}','Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_r.tif');
copyfile Lp_r.tif '.\Images\'
delete Lp_r.tif
close all
clear LOBF_x LOBF_y


%% FIGURE 3

% EFFECTIVE HEIGHT

%LOBF equation
LOBF_x=[1:1:60];
LOBF_y=241.66*LOBF_x.^0.6431;
% Wall Length 
fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(He/1000,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y/1000,'k--','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 60 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:20:60]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Shear Span ({\itM/V=H_e}) [m]');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Plastic Hinge Length ({\itL_p}) [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-7.5,5*0.9,'c)','Color','black','FontSize',12) 
text(1,5*0.95,'{\it R^2=0.60}','Color','red','FontSize',10) 
text(2,5*0.85,'242{\it(M/V)}^{0.60}','Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_He.tif');
copyfile Lp_He.tif '.\Images\'
delete Lp_He.tif
close all
clear LOBF_x LOBF_y

%% FIGURE 4

% AXIAL LOAD RATIO

%LOBF equation
LOBF_x=[0:0.05:1];
LOBF_y=-1623.2*LOBF_x+1456.3;
% Wall Length 
fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(ALR,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y/1000,'k--','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 1 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:0.2:1]);
set(ax1,'ytick',[]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

ax = gca;
ax.Clipping = 'on';

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Axial Load Ratio ({\itALR})');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Plastic Hinge Length ({\itL_p}) [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.15,5*0.9,'d)','Color','black','FontSize',12) 
text(0.45,5*0.95,'{\it R^2=0.03}','Color','red','FontSize',10) 
text(0.25,5*0.85,'-1623{\itALR}+1456','Color','red','FontSize',10) 

text(-0.1,5,'5','Color','black','FontSize',9) 
text(-0.1,4,'4','Color','black','FontSize',9) 
text(-0.1,3,'3','Color','black','FontSize',9) 
text(-0.1,2,'2','Color','black','FontSize',9) 
text(-0.1,1,'1','Color','black','FontSize',9) 

print(gcf, '-dtiff', 'Lp_ALR.tif');
copyfile Lp_ALR.tif '.\Images\'
delete Lp_ALR.tif
close all
clear LOBF_x LOBF_y


%% FIGURE 5

% SHEAR DEMAND

%LOBF equation
LOBF_x=[0:0.05:2];
for i=1:length(LOBF_x)
    LOBF_y(i)=-407.3*log(LOBF_x(i))+678.6;
end
% Wall Length 
fs=10;              %font and size for output of figure
fn='Arial';
set(0,'DefaultAxesFontName',fn)
set(0,'DefaultAxesFontSize',fs)
set(0,'DefaultTextFontSize',fs)
set(0,'DefaultTextFontName',fn)
figure
set(gcf,'Units','Centimeters');
set(gcf,'Position',[10 7 5 6]); %size of the figure
set(gcf,'PaperPositionMode','auto');
set(gcf,'Resize','Off');
set(gcf,'color','w');   %white background
% dataset
scatter(v,Lp/1000,'MarkerEdgeColor',[0.25 0.25 0.25],'LineWidth',1.0); hold on
%line-of-best-fit
plot(LOBF_x,LOBF_y/1000,'k--','color',[1 0 0],'LineWidth',2); hold on

ax1 = gca; % current axes
ax1.XColor = 'k';
ax1.YColor = 'k';
ax1_pos = ax1.Position; % position of first axes
ax1=gca; % current axes
p=get(ax1,'Position');
set(ax1, 'Units', 'Normalized', 'Position', [.20    0.1700    0.70    0.7850]);
set(ax1,'XAxisLocation','bottom');
set(ax1,'YAxisLocation','left');
axis([0 2 0 5]);
X=get(ax1,'XLim'); Y=get(gca,'YLim');
set(ax1,'xtick',[0:0.4:2]);
set(ax1,'ytick',[0:1:5]);
set(ax1,'XMinorTick','on');
set(ax1,'YMinorTick','on');
set(ax1,'TickLength',[0.02 1]);

%legend
%leg=legend('Exp','V4');
%set(leg,'Color','none');
%set(leg,'Location','SouthEast');
%set(leg,'Units','normalized');

XL=xlabel('Shear stress parameter ({\it\nu})');
set(XL,'Units','normalized');
set(XL,'HorizontalAlignment','center');
set(XL,'VerticalAlignment','Middle');
set(XL,'Position',[0.5   -0.15   0]);
%Y-axis Label
YL=ylabel('Plastic Hinge Length ({\itL_p}) [m]');
set(YL,'Units','normalized');
set(YL,'HorizontalAlignment','center');
set(YL,'VerticalAlignment','Middle');
set(YL,'Position',[-0.20    0.55  0]);

text(-0.25,5*0.9,'e)','Color','black','FontSize',12) 
text(0.9,5*0.95,'{\it R^2=0.11}','Color','red','FontSize',10) 
text(0.6,5*0.85,'-407ln({\it\nu})+679','Color','red','FontSize',10) 
print(gcf, '-dtiff', 'Lp_v.tif');
copyfile Lp_v.tif '.\Images\'
delete Lp_v.tif
close all
clear LOBF_x LOBF_y